@@ -12,6 +12,7 @@
 module Numeric.Interval
   ( Interval
   , (...)
+  , (+/-)
   , interval
   , whole
   , empty
@@ -31,6 +32,8 @@ module Numeric.Interval
   , magnitude
   , mignitude
   , distance
+  , inflate, deflate
+  , scale, symmetric
   , contains
   , isSubsetOf
   , certainly, (<!), (<=!), (==!), (>=!), (>!)
