@@ -1,7 +1,7 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE Rank2Types #-}
 {-# LANGUAGE DeriveDataTypeable #-}
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE DeriveGeneric #-}
 #endif
 {-# OPTIONS_HADDOCK not-home #-}
@@ -20,6 +20,7 @@
 module Numeric.Interval.Internal
   ( Interval(..)
   , (...)
+  , (+/-)
   , interval
   , whole
   , empty
@@ -39,6 +40,8 @@ module Numeric.Interval.Internal
   , magnitude
   , mignitude
   , distance
+  , inflate, deflate
+  , scale, symmetric
   , contains
   , isSubsetOf
   , certainly, (<!), (<=!), (==!), (>=!), (>!)
@@ -49,10 +52,14 @@ module Numeric.Interval.Internal
 
 import Control.Exception as Exception
 import Data.Data
-import Data.Foldable hiding (minimum, maximum, elem, notElem)
+import Data.Foldable hiding (minimum, maximum, elem, notElem
+#if __GLASGOW_HASKELL__ >= 710
+  , null
+#endif
+  )
 import Data.Function (on)
 import Data.Monoid
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
 import GHC.Generics
 #endif
 import Numeric.Interval.Exception
@@ -63,7 +70,7 @@ import Prelude hiding (null, elem, notElem)
 data Interval a = I !a !a | Empty deriving
   ( Data
   , Typeable
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
   , Generic
 #if __GLASGOW_HASKELL__ >= 706
   , Generic1
@@ -77,6 +84,10 @@ instance Foldable Interval where
   {-# INLINE foldMap #-}
 
 infix 3 ...
+infixl 6 +/-
+
+(+/-) :: (Num a, Ord a) => a -> a -> Interval a
+a +/- b = a - b ... a + b
 
 negInfinity :: Fractional a => a
 negInfinity = (-1)/0
@@ -261,6 +272,69 @@ mignitude = inf . abs
 distance :: (Num a, Ord a) => Interval a -> Interval a -> a
 distance i1 i2 = mignitude (i1 - i2)
 
+-- | Inflate an interval by enlarging it at both ends.
+--
+-- >>> inflate 3 (-1 ... 7)
+-- -4 ... 10
+--
+-- >>> inflate (-2) (0 ... 4)
+-- -2 ... 6
+--
+-- >>> inflate 1 empty
+-- Empty
+inflate :: (Num a, Ord a) => a -> Interval a -> Interval a
+inflate x y = symmetric x + y
+
+-- | Deflate an interval by shrinking it from both ends.
+--
+-- >>> deflate 3.0 (-4.0 ... 10.0)
+-- -1.0 ... 7.0
+--
+-- >>> deflate 2.0 (-1.0 ... 1.0)
+-- Empty
+--
+-- >>> deflate 1.0 empty
+-- Empty
+deflate :: (Fractional a, Ord a) => a -> Interval a -> Interval a
+deflate _ Empty               = Empty
+deflate x (I a b) | a' <= b'  = I a' b'
+                  | otherwise = Empty
+  where
+    a' = a + x
+    b' = b - x
+
+-- | Scale an interval about its midpoint.
+--
+-- >>> scale 1.1 (-6.0 ... 4.0)
+-- -6.5 ... 4.5
+--
+-- >>> scale (-2.0) (-1.0 ... 1.0)
+-- Empty
+--
+-- >>> scale 3.0 empty
+-- Empty
+scale :: (Fractional a, Ord a) => a -> Interval a -> Interval a
+scale _ Empty = Empty
+scale x i = a ... b where
+  h = x * width i / 2
+  mid = midpoint i
+  a = mid - h
+  b = mid + h
+
+-- | Construct a symmetric interval.
+--
+-- >>> symmetric 3
+-- -3 ... 3
+--
+-- >>> symmetric (-2)
+-- -2 ... 2
+symmetric :: (Num a, Ord a) => a -> Interval a
+symmetric x | a <= b    = I a b
+            | otherwise = I b a
+  where
+    a = negate x
+    b = x
+
 instance (Num a, Ord a) => Num (Interval a) where
   I a b + I a' b' = (a + a') ... (b + b')
   _ + _ = Empty
@@ -592,7 +666,7 @@ instance RealFloat a => RealFloat (Interval a) where
 --
 -- >>> intersection (1 ... 10 :: Interval Double) (5 ... 15 :: Interval Double)
 -- 5.0 ... 10.0
-intersection :: (Fractional a, Ord a) => Interval a -> Interval a -> Interval a
+intersection :: Ord a => Interval a -> Interval a -> Interval a
 intersection x@(I a b) y@(I a' b')
   | x /=! y   = Empty
   | otherwise = I (max a a') (min b b')
