@@ -1,7 +1,7 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE Rank2Types #-}
 {-# LANGUAGE DeriveDataTypeable #-}
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE DeriveGeneric #-}
 #endif
 {-# OPTIONS_HADDOCK not-home #-}
@@ -41,6 +41,8 @@ module Numeric.Interval.NonEmpty.Internal
   , certainly, (<!), (<=!), (==!), (>=!), (>!)
   , possibly, (<?), (<=?), (==?), (>=?), (>?)
   , clamp
+  , inflate, deflate
+  , scale, symmetric
   , idouble
   , ifloat
   ) where
@@ -50,7 +52,7 @@ import Data.Data
 import Data.Foldable hiding (minimum, maximum, elem, notElem)
 import Data.Function (on)
 import Data.Monoid
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
 import GHC.Generics
 #endif
 import Numeric.Interval.Exception
@@ -61,7 +63,7 @@ import Prelude hiding (null, elem, notElem)
 data Interval a = I !a !a deriving
   ( Data
   , Typeable
-#if defined(__GLASGOW_HASKELL) && __GLASGOW_HASKELL__ >= 704
+#if __GLASGOW_HASKELL__ >= 704
   , Generic
 #if __GLASGOW_HASKELL__ >= 706
   , Generic1
@@ -471,7 +473,7 @@ instance RealFloat a => RealFloat (Interval a) where
 --
 -- >>> intersection (1 ... 10 :: Interval Double) (5 ... 15 :: Interval Double)
 -- Just (5.0 ... 10.0)
-intersection :: (Fractional a, Ord a) => Interval a -> Interval a -> Maybe (Interval a)
+intersection :: Ord a => Interval a -> Interval a -> Maybe (Interval a)
 intersection x@(I a b) y@(I a' b')
   | x /=! y   = Nothing
   | otherwise = Just $ I (max a a') (min b b')
@@ -655,6 +657,56 @@ clamp (I a b) x
   | x > b     = b
   | otherwise = x
 
+-- | Inflate an interval by enlarging it at both ends.
+--
+-- >>> inflate 3 (-1 ... 7)
+-- -4 ... 10
+--
+-- >>> inflate (-2) (0 ... 4)
+-- -2 ... 6
+inflate :: (Num a, Ord a) => a -> Interval a -> Interval a
+inflate x y = symmetric x + y
+
+-- | Deflate an interval by shrinking it from both ends.
+-- Note that in cases that would result in an empty interval, the result is a singleton interval at the midpoint.
+--
+-- >>> deflate 3.0 (-4.0 ... 10.0)
+-- -1.0 ... 7.0
+--
+-- >>> deflate 2.0 (-1.0 ... 1.0)
+-- 0.0 ... 0.0
+deflate :: (Fractional a, Ord a) => a -> Interval a -> Interval a
+deflate x i@(I a b) | a' <= b'  = I a' b'
+                    | otherwise = singleton m
+  where
+    a' = a + x
+    b' = b - x
+    m = midpoint i
+
+-- | Scale an interval about its midpoint.
+--
+-- >>> scale 1.1 (-6.0 ... 4.0)
+-- -6.5 ... 4.5
+--
+-- >>> scale (-2.0) (-1.0 ... 1.0)
+-- -2.0 ... 2.0
+scale :: (Fractional a, Ord a) => a -> Interval a -> Interval a
+scale x i = a ... b where
+  h = x * width i / 2
+  mid = midpoint i
+  a = mid - h
+  b = mid + h
+
+-- | Construct a symmetric interval.
+--
+-- >>> symmetric 3
+-- -3 ... 3
+--
+-- >>> symmetric (-2)
+-- -2 ... 2
+symmetric :: (Num a, Ord a) => a -> Interval a
+symmetric x = negate x ... x
+
 -- | id function. Useful for type specification
 --
 -- >>> :t idouble (1 ... 3)
